@@ -50,7 +50,7 @@
 #' \code{vignette("mrf2d-family", package = "mrf2d")}
 #'
 #' A paper with detailed description of the package can be found at
-#' \url{https://arxiv.org/abs/2006.00383}
+#' \doi{10.18637/jss.v101.i08}.
 NULL
 
-mrf2d_families <- c("onepar", "oneeach", "absdif", "dif", "free")
+mrf2d_families <- c("onepar", "oneeach", "absdif", "dif", "symmetric", "free")
